package WebGUI::i18n::Spanish::Form_Username;
use utf8;
our $I18N = {
  'username' => {
    'lastUpdated' => '1276813152',
    'message' => 'Nombre de Usuario'
  },
  'username in use' => {
    'lastUpdated' => '1270050807',
    'message' => 'Disculpe, ese nombre de usuario ya está siendo utilizado por otro miembro del sitio.'
  }
}
;

1;
